@@ -8,13 +8,10 @@ pub use attribute_value::AttributeValue;
 pub use callback::Callback;
 pub use special::{key, replace, skip, Special};
 pub use style::Style;
-pub use style_macro::*;
 pub use value::Value;
 
 #[macro_use]
 mod attribute_macros;
-#[macro_use]
-mod style_macro;
 mod attribute_value;
 mod callback;
 mod special;
